===============================
Published work with lenstronomy
===============================

In this section you can find the concept papers **lenstronomy** is based on the list of science publications that made
use of **lenstronomy**. Please let the developers know when you publish a paper that made use of **lenstronomy**.
We are happy to include your publication in this list.


Method papers
-------------

* Gravitational Lens Modeling with Basis Sets; `Birrer et al. 2015 <http://adsabs.harvard.edu/abs/2015ApJ...813..102B>`_
    *This is the method paper **lenstronomy** is primary based on. Please cite this paper whenever you publish results with **lenstronomy** by using
    Shapelet basis sets and/or the PSO and MCMC chain.*

* Line-of-sight effects in strong lensing: putting theory into practice; `Birrer et al. 2017a <http://adsabs.harvard.edu/abs/2017JCAP...04..049B>`_
    *This paper formulates an effective parameterization of line-of-sight structure for strong gravitational lens modelling and applies this technique to an Einstein ring in the COSMOS field*

* Cosmic Shear with Einstein Rings; `Birrer et al. 2018a <http://adsabs.harvard.edu/abs/2018ApJ...852L..14B>`_
    *Forecast paper to measure cosmic shear with Einstein ring lenses. The forecast is made based on **lenstronomy** simulations.

* Is every strong lens model unhappy in its own way? Uniform modelling of a sample of 12 quadruply+ imaged quasars; `Shajib et al. 2018 <https://ui.adsabs.harvard.edu//#abs/2018arXiv180709278S/>`_
    *This work presents a uniform modelling framework to model 12 quadruply lensed quasars in three HST bands.*


Science papers
--------------

* The mass-sheet degeneracy and time-delay cosmography: analysis of the strong lens RXJ1131-1231; `Birrer et al. 2016 <http://adsabs.harvard.edu/abs/2016JCAP...08..020B>`_
    *This paper performs a cosmographic analysis and applies the Shapelet basis set scaling to marginalize over a major lensing degeneracy.*

* Lensing substructure quantification in RXJ1131-1231: a 2 keV lower bound on dark matter thermal relic mass; `Birrer et al. 2017b <http://adsabs.harvard.edu/abs/2017JCAP...05..037B>`_
    *This paper quantifies the substructure content of a lens by a sub-clump scanning procedure and the application of Approximate Bayesian Computing.*

* H0LiCOW - IX. Cosmographic analysis of the doubly imaged quasar SDSS 1206+4332 and a new measurement of the Hubble constant; `Birrer et al. 2019 <https://ui.adsabs.harvard.edu/#abs/2018arXiv180901274B/abstract>`_
    *This paper performs a cosmographic analysis with power-law and composite models and covers a range in complexity in the source reconstruction*